package de.laliluna.tutorial.databaseview.session.ejb;

import java.rmi.RemoteException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

import javax.ejb.EJBException;
import javax.ejb.FinderException;
import javax.ejb.SessionBean;
import javax.ejb.SessionContext;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;

import de.laliluna.tutorial.databaseview.entity.interfaces.BookViewLocal;
import de.laliluna.tutorial.databaseview.entity.interfaces.BookViewLocalHome;

/**
 * @author laliluna.de
 * 
 * @ejb.bean name="BookViewSession"
 *           display-name="Name for BookViewSession"
 *           description="Description for BookViewSession"
 *           jndi-name="ejb/BookViewSession"
 *           type="Stateless"
 *           view-type="both"
 */
public class BookViewSession implements SessionBean {

    
    /**
     * Return a collection of BookViewValue objects
     * 
     * @ejb.interface-method view-type = "both"
     */
    public Collection getAll() throws EJBException {

        Collection collection = null;

        try {
            Context context = new InitialContext();

            // get the local home 
            BookViewLocalHome localHome = (BookViewLocalHome) context
                    .lookup(BookViewLocalHome.JNDI_NAME);

            // get all entries of the local home
            Collection localCollection = localHome.findAll();

            // fill the collection that will be returned
            collection = new ArrayList();
            for (Iterator iter = localCollection.iterator(); iter.hasNext();) {
                BookViewLocal element = (BookViewLocal) iter.next();
                collection.add(element.getBookViewValue());
            }

        } catch (FinderException e) {
            e.printStackTrace();
        } catch (NamingException e) {
            e.printStackTrace();
        }

        return collection;
    }
    
    
    /** The session context */
    private SessionContext context;

    /**
     * Set the associated session context. The container calls this method 
     * after the instance creation.
     * 
     * The enterprise bean instance should store the reference to the context 
     * object in an instance variable.
     * 
     * This method is called with no transaction context. 
     * 
     * @throws EJBException Thrown if method fails due to system-level error.
     */
    public void setSessionContext(SessionContext newContext)
        throws EJBException {
        context = newContext;
    }

    /* (non-Javadoc)
     * @see javax.ejb.SessionBean#ejbRemove()
     */
    public void ejbRemove() throws EJBException, RemoteException {
    }

    /* (non-Javadoc)
     * @see javax.ejb.SessionBean#ejbActivate()
     */
    public void ejbActivate() throws EJBException, RemoteException {
    }

    /* (non-Javadoc)
     * @see javax.ejb.SessionBean#ejbPassivate()
     */
    public void ejbPassivate() throws EJBException, RemoteException {
    }

    /**
     * An example business method
     *
     * @ejb.interface-method view-type = "remote"
     * 
     * @throws EJBException Thrown if method fails due to system-level error.
     */
    public void replaceWithRealBusinessMethod() throws EJBException {
        // rename and start putting your business logic here
    }

}